"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const loader_util_1 = require("./loader_util");
const child_process_1 = require("child_process");
const fork_1 = require("./fork");
const EggLoader = require('egg').AgentWorkerLoader;
exports.EggLoader = EggLoader;
class AgentWorkerLoader extends EggLoader {
    constructor() {
        super(...arguments);
        this.fork = child_process_1.fork;
        this.registeredTS = false;
    }
    get baseDir() {
        return this.options.baseDir;
    }
    get etConfig() {
        return ((this.app.config && this.app.config.et) || {
            useTSRuntime: false,
        });
    }
    load() {
        if (this.etConfig.useTSRuntime) {
            loader_util_1.registerTSNode(this.baseDir);
            this.registeredTS = true;
            this.fork = (...args) => fork_1.fork(this.baseDir, ...args);
        }
        super.load();
    }
    loadFile(filepath, ...inject) {
        if (!this.registeredTS) {
            return super.loadFile(filepath, ...inject);
        }
        const tsFilePath = filepath.replace('.js', '.ts');
        if (!fs.existsSync(tsFilePath)) {
            // fallback
            return super.loadFile(filepath, ...inject);
        }
        let ret = loader_util_1.loadFile(tsFilePath);
        if ('default' in ret) {
            ret = ret.default;
        }
        // function(arg1, args, ...) {}
        if (inject.length === 0)
            inject = [this.app];
        return ret instanceof Function ? ret(...inject) : ret;
    }
}
exports.default = AgentWorkerLoader;
